@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Choice.cxx 4288 2005-04-16 00:13:17Z mike $"
+// "$Id: Fl_Choice.cxx 5485 2006-09-24 13:35:23Z mike $"
 //
 // Choice widget for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2005 by Bill Spitzak and others.
+// Copyright 1998-2006 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -28,6 +28,7 @@
 #include <FL/Fl.H>
 #include <FL/Fl_Choice.H>
 #include <FL/fl_draw.H>
+#include "flstring.h"
 
 // Emulates the Forms choice widget.  This is almost exactly the same
 // as an Fl_Menu_Button.  The only difference is the appearance of the
@@ -48,11 +49,26 @@ void Fl_Choice::draw() {
     draw_box(FL_UP_BOX, color());
 
     fl_color(active_r() ? labelcolor() : fl_inactive(labelcolor()));
-    fl_polygon(x1, y1 + 3, x1 + w1, y1 + w1 + 3, x1 + 2 * w1, y1 + 3);
-    fl_polygon(x1, y1 + 1, x1 + w1, y1 - w1 + 1, x1 + 2 * w1, y1 + 1);
+    if (!strcmp(Fl::scheme(), "plastic")) {
+      // Show larger up/down arrows...
+      fl_polygon(x1, y1 + 3, x1 + w1, y1 + w1 + 3, x1 + 2 * w1, y1 + 3);
+      fl_polygon(x1, y1 + 1, x1 + w1, y1 - w1 + 1, x1 + 2 * w1, y1 + 1);
+    } else {
+      // Show smaller up/down arrows with a divider...
+      x1 = x() + w() - 13 - dx;
+      y1 = y() + h() / 2;
+      fl_polygon(x1, y1 - 2, x1 + 3, y1 - 5, x1 + 6, y1 - 2);
+      fl_polygon(x1, y1 + 2, x1 + 3, y1 + 5, x1 + 6, y1 + 2);
+
+      fl_color(fl_darker(color()));
+      fl_yxline(x1 - 7, y1 - 8, y1 + 8);
+
+      fl_color(fl_lighter(color()));
+      fl_yxline(x1 - 6, y1 - 8, y1 + 8);
+    }
   } else {
-    draw_box(FL_DOWN_BOX, color());
-    draw_box(FL_UP_BOX,X,Y,W,H,FL_GRAY);
+    draw_box(FL_DOWN_BOX, FL_BACKGROUND2_COLOR);
+    draw_box(FL_UP_BOX,X,Y,W,H,color());
 
     fl_color(active_r() ? labelcolor() : fl_inactive(labelcolor()));
     fl_polygon(x1, y1, x1 + w1, y1 + w1, x1 + 2 * w1, y1);
@@ -103,7 +119,6 @@ Fl_Choice::Fl_Choice(int X, int Y, int W, int H, const char *l)
   textfont(FL_HELVETICA);
   box(FL_FLAT_BOX);
   down_box(FL_BORDER_BOX);
-  color(FL_BACKGROUND2_COLOR);
 }
 
 int Fl_Choice::value(const Fl_Menu_Item *v) {
@@ -134,7 +149,16 @@ int Fl_Choice::handle(int e) {
   case FL_PUSH:
     if (Fl::visible_focus()) Fl::focus(this);
   J1:
-    v = menu()->pulldown(x(), y(), w(), h(), mvalue(), this);
+    if (Fl::scheme()) {
+      v = menu()->pulldown(x(), y(), w(), h(), mvalue(), this);
+    } else {
+      // In order to preserve the old look-n-feel of "white" menus,
+      // temporarily override the color() of this widget...
+      Fl_Color c = color();
+      color(FL_BACKGROUND2_COLOR);
+      v = menu()->pulldown(x(), y(), w(), h(), mvalue(), this);
+      color(c);
+    }
     if (!v || v->submenu()) return 1;
     if (v != mvalue()) redraw();
     picked(v);
@@ -158,5 +182,5 @@ int Fl_Choice::handle(int e) {
 }
 
 //
-// End of "$Id: Fl_Choice.cxx 4288 2005-04-16 00:13:17Z mike $".
+// End of "$Id: Fl_Choice.cxx 5485 2006-09-24 13:35:23Z mike $".
 //
