@@ -1,5 +1,5 @@
 //
-// "$Id: fl_draw.cxx 4670 2005-11-29 08:49:56Z mike $"
+// "$Id: fl_draw.cxx 5565 2006-12-21 19:39:26Z mike $"
 //
 // Label drawing code for the Fast Light Tool Kit (FLTK).
 //
@@ -95,7 +95,11 @@ expand(const char* from, char* buf, double maxw, int& n, double &width,
     } else if (c < ' ' || c == 127) { // ^X
       *o++ = '^';
       *o++ = c ^ 0x40;
-    } else if (c == 0xA0) { // non-breaking space
+#ifdef __APPLE__
+    } else if (c == 0xCA) { // non-breaking space in MacRoman
+#else
+    } else if (c == 0xA0) { // non-breaking space in ISO 8859
+#endif
       *o++ = ' ';
     } else if (c == '@' && draw_symbols) { // Symbol???
       if (p[1] && p[1] != '@')  break;
@@ -154,15 +158,13 @@ void fl_draw(
 
   symtotal = symwidth[0] + symwidth[1];
 
-  if (str) {
-    for (p = str, lines=0; p;) {
-      e = expand(p, buf, w - symtotal, buflen, width, align&FL_ALIGN_WRAP,
-                 draw_symbols);
-      lines++;
-      if (!*e || (*e == '@' && e[1] != '@' && draw_symbols)) break;
-      p = e;
-    }
-  } else lines = 0;
+  for (p = str, lines=0; p;) {
+    e = expand(p, buf, w - symtotal, buflen, width, align&FL_ALIGN_WRAP,
+               draw_symbols);
+    lines++;
+    if (!*e || (*e == '@' && e[1] != '@' && draw_symbols)) break;
+    p = e;
+  }
 
   if ((symwidth[0] || symwidth[1]) && lines) {
     if (symwidth[0]) symwidth[0] = lines * fl_height();
@@ -291,19 +293,21 @@ void fl_measure(const char* str, int& w, int& h, int draw_symbols) {
   symbol[1][0] = '\0';
   symwidth[1]  = 0;
 
-  if (str && str[0] == '@' && str[1] && str[1] != '@') {
-    // Start with a symbol...
-    for (symptr = symbol[0];
-         *str && !isspace(*str) && symptr < (symbol[0] + sizeof(symbol[0]) - 1);
-         *symptr++ = *str++);
-    *symptr = '\0';
-    if (isspace(*str)) str++;
-    symwidth[0] = h;
-  }
+  if (draw_symbols) {
+    if (str && str[0] == '@' && str[1] && str[1] != '@') {
+      // Start with a symbol...
+      for (symptr = symbol[0];
+           *str && !isspace(*str) && symptr < (symbol[0] + sizeof(symbol[0]) - 1);
+           *symptr++ = *str++);
+      *symptr = '\0';
+      if (isspace(*str)) str++;
+      symwidth[0] = h;
+    }
 
-  if (str && (p = strrchr(str, '@')) != NULL && p > (str + 1)) {
-    strlcpy(symbol[1], p, sizeof(symbol[1]));
-    symwidth[1] = h;
+    if (str && (p = strrchr(str, '@')) != NULL && p > (str + 1) && p[-1]!='@') {
+      strlcpy(symbol[1], p, sizeof(symbol[1]));
+      symwidth[1] = h;
+    }
   }
 
   symtotal = symwidth[0] + symwidth[1];
@@ -322,11 +326,11 @@ void fl_measure(const char* str, int& w, int& h, int draw_symbols) {
   }
 
   symtotal = symwidth[0] + symwidth[1];
-  
+
   w = W + symtotal;
   h = lines*h;
 }
 
 //
-// End of "$Id: fl_draw.cxx 4670 2005-11-29 08:49:56Z mike $".
+// End of "$Id: fl_draw.cxx 5565 2006-12-21 19:39:26Z mike $".
 //
