@@ -1,5 +1,5 @@
 //
-// "$Id: fl_draw_pixmap.cxx 4723 2005-12-30 10:13:17Z matt $"
+// "$Id: fl_draw_pixmap.cxx 6026 2008-02-14 18:17:06Z matt $"
 //
 // Pixmap drawing code for the Fast Light Tool Kit (FLTK).
 //
@@ -322,11 +322,10 @@ int fl_draw_pixmap(const char*const* di, int x, int y, Fl_Color bg) {
         src, 0L, false, kCGRenderingIntentDefault);
   CGColorSpaceRelease(lut);
   CGDataProviderRelease(src);
-  CGRect rect = { x, y, d.w, d.h };
-  Fl_X::q_begin_image(rect, x, y, d.w, d.h);
+  CGRect rect = { { x, y} , { d.w, d.h } };
+  Fl_X::q_begin_image(rect, 0, 0, d.w, d.h);
   CGContextDrawImage(fl_gc, rect, img);
   Fl_X::q_end_image();
-  CGContextFlush(fl_gc);
   CGImageRelease(img);
   delete array;
 
@@ -337,5 +336,5 @@ int fl_draw_pixmap(const char*const* di, int x, int y, Fl_Color bg) {
 }
 
 //
-// End of "$Id: fl_draw_pixmap.cxx 4723 2005-12-30 10:13:17Z matt $".
+// End of "$Id: fl_draw_pixmap.cxx 6026 2008-02-14 18:17:06Z matt $".
 //
