@@ -1,5 +1,5 @@
 //
-// "$Id: fl_shortcut.cxx 4727 2005-12-30 14:11:04Z matt $"
+// "$Id: fl_shortcut.cxx 5981 2007-11-19 16:21:19Z matt $"
 //
 // Shortcut support routines for the Fast Light Tool Kit (FLTK).
 //
@@ -55,7 +55,12 @@ int Fl::test_shortcut(int shortcut) {
   if (!shortcut) return 0;
 
   int v = shortcut & 0xffff;
-  if (v > 32 && v < 0x7f || v > 0xa0 && v <= 0xff) {
+#ifdef __APPLE__
+  if (v > 32 && v < 0x7f || v >= 0x80 && v <= 0xff) {
+#else
+  // most X11 use MSWindows Latin-1 if set to Western encoding, so 0x80 to 0xa0 are defined
+  if (v > 32 && v < 0x7f || v >= 0x80 && v <= 0xff) {
+#endif
     if (isupper(v)) {
       shortcut |= FL_SHIFT;
     }
@@ -127,7 +132,11 @@ const char * fl_shortcut_label(int shortcut) {
   if (!shortcut) {*p = 0; return buf;}
   // fix upper case shortcuts
   int v = shortcut & 0xffff;
-  if (v > 32 && v < 0x7f || v > 0xa0 && v <= 0xff) {
+#ifdef __APPLE__
+  if (v > 32 && v < 0x7f || v >= 0x80 && v <= 0xff) {
+#else
+  if (v > 32 && v < 0x7f || v >= 0xa0 && v <= 0xff) {
+#endif
     if (isupper(v)) {
       shortcut |= FL_SHIFT;
     }
@@ -198,24 +207,33 @@ int fl_old_shortcut(const char* s) {
 
 // Tests for &x shortcuts in button labels:
 
-int Fl_Widget::test_shortcut(const char *l) {
-  char c = Fl::event_text()[0];
-  if (!c || !l) return 0;
+char Fl_Widget::label_shortcut(const char *t) {
+  if (!t) return 0;
   for (;;) {
-    if (!*l) return 0;
-    if (*l++ == '&' && *l) {
-      if (*l == '&') l++;
-      else if (*l == c) return 1;
-      else return 0;
+    if (*t==0) return 0;
+    if (*t=='&') {
+      char s = t[1];
+      if (s==0) return 0;
+      else if (s=='&') t++;
+      else return s;
     }
+    t++;
   }
 }
 
+int Fl_Widget::test_shortcut(const char *t) {
+  char c = Fl::event_text()[0];
+  if (!c || !t) return 0;
+  if (c == label_shortcut(t))
+    return 1;
+  return 0;
+}
+
 int Fl_Widget::test_shortcut() {
   if (!(flags()&SHORTCUT_LABEL)) return 0;
   return test_shortcut(label());
 }
 
 //
-// End of "$Id: fl_shortcut.cxx 4727 2005-12-30 14:11:04Z matt $".
+// End of "$Id: fl_shortcut.cxx 5981 2007-11-19 16:21:19Z matt $".
 //
